from random import random


def play_even_game(name):
    """Brain-even

        Answer "yes" if the number is even, otherwise answer "no".
    """

    print('Answer "yes" if the number is even, otherwise answer "no".')

    win = 0
    while win < 3:
        rand_int = int(random() * 100)
        correct_answer = 'yes' if rand_int % 2 == 0 else 'no'
        print(f'Question: {rand_int}')
        answer = input('Your answer: ')
        if answer != correct_answer:
            print(f"'{answer}' is wrong answer ;(. Correct answer was '{correct_answer}'.\n \
                Let's try again, {name}!")
            break
        else:
            print('Correct!')
            win += 1
        if win == 3:
            print(f'Congratulations, {name}!')



from brain_games.cli import welcome_user
from brain_games.even_game import play_even_game


def main():
    """Brain-even main"""

    user_name = welcome_user()
    play_even_game(user_name)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['brain_games', 'brain_games.scripts']

package_data = \
{'': ['*']}

install_requires = \
['prompt>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['brain-even = brain_games.scripts.brain_even:main',
                     'brain-games = brain_games.scripts.brain_games:main']}

setup_kwargs = {
    'name': 'izvekovweb-project-1',
    'version': '0.1.1',
    'description': 'Игры разума',
    'long_description': None,
    'author': 'Alexander Izvekov',
    'author_email': 'izvekov.web@yandex.ru',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
